@@ -4,7 +4,7 @@ use warnings;
 use Dancer::Plugin;
 use Net::STOMP::Client;
 
-our $VERSION = '1.0000'; # VERSION
+our $VERSION = '1.0001'; # VERSION
 
 my %stomps;
 
@@ -21,7 +21,7 @@ register stomp => sub {
     my $params = $config->{$name}
         or die "The Stomp client '$name' is not configured";
 
-    my $host = $params->{host} || $params->{hostname};
+    my $host = $params->{host} || $params->{hostname}
         or die "The Stomp server host is missing";
 
     my $port = 61613;
@@ -59,7 +59,7 @@ Dancer::Plugin::Stomp - A Dancer plugin for talking to STOMP message brokers.
 
 =head1 VERSION
 
-version 1.0000
+version 1.0001
 
 =head1 SYNOPSIS
 
